==> cosmo_1.6.0.tar.gz: cosmo/man/makeShapeDiffCon.Rd <==
\name{makeShapeDiffCon}
\alias{makeShapeDiffCon}
\title{Constructing a shape parameter difference constraint}
\description{
  This function constructs a \texttt{shapeDiffCon} object representing a
  constraint on the unknown position weight matrix that requires the
  the difference between the information content at the edge of one
  interval and the information content at the edge of another interval
  to be bounded betwene given bounds. This constraint may only be applied to
  intervals that already have a shape constraint.
}
\usage{
makeShapeDiffCon(int1, int2, lower, upper)
}
\arguments{
  \item{int1}{\code{character} the location of the first information
    content of interest. This is specified as the number of the interval
  followed by the letter \code{a} or \code{b} depending on whether the
  left or right edge of the interval is desired.}
  \item{int2}{\code{character} the location of the second information
    content of interest. This is specified as the number of the interval
  followed by the letter \code{a} or \code{b} depending on whether the
  left or right edge of the interval is desired.}
  \item{lower}{\code{numeric} the lower bound on the difference in
    information contents.}
  \item{upper}{\code{numeric} the upper bound on the difference in
    information contents.}

}
\details{
}
\value{
An object of class \texttt{shapeDiffCon}.
}
\author{
Fabian Gallusser, \email{fgallusser@berkeley.edu}
}
\seealso{
  \code{\link{boundCon}}, \code{\link{shapeCon}}, \code{\link{subMotifCon}}, \code{\link{posFreqCon}}, \code{\link{shapeDiffCon}}, \code{\link{palCon}}
}
\examples{
## continuous information content across interval 1
sdc1 <- makeShapeDiffCon("1a", "1b", 0.0, 0.0)

## continuous information content at junction
## between intervals 1 and 2
sdc2 <- makeShapeDiffCon("1b", "2a", 0.0, 0.0)

## decreasing information content across interval 1
sdc3 <- makeShapeDiffCon("1a", "1b", 0.0, 2.0)
}
\keyword{misc}

==> cosmo_1.18.0.tar.gz: cosmo/man/makeShapeDiffCon.Rd <==
\name{makeShapeDiffCon}
\alias{makeShapeDiffCon}
\title{Constructing a shape parameter difference constraint}
\description{
  This function constructs a \code{shapeDiffCon} object representing a
  constraint on the unknown position weight matrix that requires the
  the difference between the information content at the edge of one
  interval and the information content at the edge of another interval
  to be bounded betwene given bounds. This constraint may only be applied to
  intervals that already have a shape constraint.
}
\usage{
makeShapeDiffCon(int1, int2, lower, upper)
}
\arguments{
  \item{int1}{\code{character} the location of the first information
    content of interest. This is specified as the number of the interval
  followed by the letter \code{a} or \code{b} depending on whether the
  left or right edge of the interval is desired.}
  \item{int2}{\code{character} the location of the second information
    content of interest. This is specified as the number of the interval
  followed by the letter \code{a} or \code{b} depending on whether the
  left or right edge of the interval is desired.}
  \item{lower}{\code{numeric} the lower bound on the difference in
    information contents.}
  \item{upper}{\code{numeric} the upper bound on the difference in
    information contents.}

}
\details{
}
\value{
An object of class \code{shapeDiffCon}.
}
\author{
Fabian Gallusser, \email{fgallusser@berkeley.edu}
}
\seealso{
  \code{\link{boundCon}}, \code{\link{shapeCon}}, \code{\link{subMotifCon}}, \code{\link{posFreqCon}}, \code{\link{shapeDiffCon}}, \code{\link{palCon}}
}
\examples{
## continuous information content across interval 1
sdc1 <- makeShapeDiffCon("1a", "1b", 0.0, 0.0)

## continuous information content at junction
## between intervals 1 and 2
sdc2 <- makeShapeDiffCon("1b", "2a", 0.0, 0.0)

## decreasing information content across interval 1
sdc3 <- makeShapeDiffCon("1a", "1b", 0.0, 2.0)
}
\keyword{misc}
